@@ -53,7 +53,7 @@ module TransformerPlugin
         end
 
 	def generate(task, config)
-            task.project.using_library('transformer', :typekit => false)
+            task.project.using_library('transformer', :typekit => true)
             port_listener_ext = task.extension("port_listener", false)
 
             if !(tr = config.task.superclass.find_extension('transformer')) || !tr.needs_transformer?
@@ -715,7 +715,7 @@ module TransformerPlugin
                     multiplexes.
                     needs_reliable_connection
             end
-                
+
             # Add period property for every data stream
             streams.each do |stream|
                 property_name = "#{stream.name}_period"
@@ -732,7 +732,31 @@ module TransformerPlugin
                     task.property("#{name}_frame", "/std/string", name).
                         doc("the global name that should be used for the internal #{name} frame")
                 end
-            end
+            end            
+        end
+        
+        def get_transform_code
+            #also do frame mapping in case the transformations are requested
+            frame_selection = configurable_frames.sort.map do |frame_name|
+                "    _#{name}.setFrameMapping(\"#{frame_name}\", _#{frame_name}_frame);"
+            end.compact
+            #add method to request needed transformations
+            frame_selection.join("\n") + " \n
+    std::vector<transformer::TransformationDescription > ret;
+    const std::vector<transformer::Transformation *> &transformations(_transformer.getRegisteredTransformations());
+    ret.reserve(transformations.size());
+    
+    for(std::vector<transformer::Transformation *>::const_iterator transform = transformations.begin();
+        transform != transformations.end(); transform++)
+    {
+        transformer::TransformationDescription curTr;
+        curTr.sourceFrame = (*transform)->getSourceFrame();
+        curTr.targetFrame = (*transform)->getTargetFrame();
+        
+        ret.push_back(curTr);
+    }
+    
+    return ret;"
         end
 
         # Lists the frames for which a configuration interface should be
@@ -775,6 +799,17 @@ module TransformerPlugin
         def needs_transformer?
             !needed_transformations.empty? || !streams.empty? || supercall(nil, :needs_transformer?)
         end
+        
+        
+        # Called by the oroGen C++ code generator to add code objects to the
+        # task implementation
+        def early_register_for_generation(task)
+            if needs_transformer?
+                task.hidden_operation("getNeededTransformations").
+                    base_body(get_transform_code).
+                    returns('std::vector<transformer::TransformationDescription>')
+            end
+        end
 
         # Called by the oroGen C++ code generator to add code objects to the
         # task implementation
